@@ -191,6 +191,9 @@ class API(Record('url', 'http')):
             <intessa.API(u'http://example.com/foo.js%20o%25n')>
         """
 
+        if not isinstance(item, basestring):
+            item = unicode(item)
+
         # Replace whole path with a new one.
         if item.startswith('/'):
             return self.url.with_path(item[1:])
